@@ -1,6 +1,7 @@
 ;;; viper-ex.el --- functions implementing the Ex commands for Viper
 
-;; Copyright (C) 1994, 95, 96, 97, 98, 2000, 01, 02, 2005 Free Software Foundation, Inc.
+;; Copyright (C) 1994, 1995, 1996, 1997, 1998, 2000, 2001, 2002, 2003,
+;;   2004, 2005, 2006 Free Software Foundation, Inc.
 
 ;; Author: Michael Kifer <kifer@cs.stonybrook.edu>
 
@@ -207,12 +208,12 @@
 
 ;; If this is a one-letter magic command, splice in args.
 (defun ex-splice-args-in-1-letr-cmd (key list)
-  (let ((onelet (ex-cmd-is-one-letter (assoc (substring key 0 1) list))))
-    (if onelet
+  (let ((oneletter (ex-cmd-is-one-letter (assoc (substring key 0 1) list))))
+    (if oneletter
 	(list key
-	      (append (cadr onelet)
+	      (append (cadr oneletter)
 		      (if (< 1 (length key)) (list (substring key 1))))
-	      (caddr onelet)))
+	      (car (cdr (cdr oneletter))) ))
 	))
 
 
@@ -1589,7 +1590,7 @@ reversed."
 
 ;; Ex print working directory
 (defun ex-pwd ()
-  (message default-directory))
+  (message "%s" default-directory))
 
 ;; Ex quit command
 (defun ex-quit ()
@@ -1623,8 +1624,9 @@ reversed."
 	(progn
 	  (setq command
 		;; replace # and % with the previous/current file
-		(ex-expand-filsyms (concat ex-file ex-cmdfile-args)
-				   (current-buffer)))
+		(ex-expand-filsyms
+		 (concat (shell-quote-argument ex-file) ex-cmdfile-args)
+		 (current-buffer)))
 	  (shell-command command t))
       (insert-file-contents ex-file)))
   (ex-fixup-history viper-last-ex-prompt ex-file ex-cmdfile-args))
@@ -2229,7 +2231,7 @@ Type 'mak ' (including the space) to run make with no args."
 		       (if (buffer-modified-p) "[Modified]" "[Unchanged]")))
     (if (< (+ 1 (length info) (length file))
 	   (window-width (minibuffer-window)))
-	(message (concat file " " info))
+	(message "%s" (concat file " " info))
       (save-window-excursion
 	(with-output-to-temp-buffer " *viper-info*"
 	  (princ (concat "\n" file "\n\n\t" info "\n\n")))
